#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/preinstall.sh - pre-installation file for owncloud/nextcloud on EIS/FAIR
#
# Copyright (c) 2012-2020  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:    2012-04-22 schlotze
# Last Update: $Id: preinstall.sh 79529 2020-07-18 17:07:39Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

# file names and pathes
module_name='owncloud'

# debug mode: true/false
#debug=true
if ${debug:-false}
then
    exec 2> /tmp/${module_name}-preinstall-trace$$.log
    set -x
    ask_debug=true
    export ask_debug
fi

installfile=/var/run/${module_name}.install
configfile=/etc/config.d/${module_name}
deinstallfile=/var/install/deinstall/${module_name}

# extract shared library file from archive
# to be able to use the myecho command
archivefile=`find /tmp -maxdepth 1 -type l -name "${module_name}.tar.*" ! -name "*.info" | head -n1`

if [ -n "${archivefile}" ]
then
    if [ -s "${archivefile}" ]
    then
        tar xjf ${archivefile} var/install/include/jedlib.${module_name} -C /

        srcfile=/var/install/include/jedlib.${module_name}
        destfile=/var/install/include/jedlib

        if [ -f ${srcfile} ]
        then
            if [ -f ${destfile} ]
            then
                srcver=`/bin/sh ${srcfile} version`
                destver=`/bin/sh ${destfile} version`

                if [ -n "${destver}" ]
                then
                    # version number exists - compare version numbers
                    if [ `echo "${srcver} > ${destver}" | bc` -eq 1 ]
                    then
                        # update file
                        echo "updating shared library file (${destver}->${srcver}) ..."
                        mv -v ${srcfile} ${destfile}
                    fi
                else
                    # no version number exists - update file
                    echo "updating shared library file ..."
                    mv -v ${srcfile} ${destfile}
                fi
            else
                # file doesn't exist - update file
                echo "updating shared library file ..."
                mv -v ${srcfile} ${destfile}
            fi
        fi
    fi
fi

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

# required versions
myecho --pack ${module_name} --info "running preinstall.sh ..."

if [ "`/usr/bin/eisman check ${module_name}`" = 'installed' ]
then
    # check if a specific package version is installed before an update will be allowed.
    if [ "${module_name}" = 'nextcloud' ]
    then
        min_required='1.8.2'
        max_required='1.9.5'
    else
        min_required='1.9.3'
        max_required='1.10.2'
    fi

    min_version=`/usr/bin/eisman check ${module_name} ${min_required}`
    max_version=`/usr/bin/eisman check ${module_name} ${max_required}`

    if [ "${min_version}" = 'new' ]
    then
        # invalid version
        myecho --pack ${module_name} --force-output --warn "You need to install the ${module_name} package v${min_required} or higher to install this package."
        exit 1
    fi

    # Do not allow to install this version if a newer package
    # has already been installed previously
    if [ "${max_version}" = 'old' ]
    then
        found_version=`/usr/bin/eisman query --fields version --installed ${module_name} | grep -v "^\-----" | sed 's/^version *//' | tail -n1`

        myecho --pack ${module_name} --force-output --warn "This package cannot be installed because a newer version ${found_version}"
        myecho --pack ${module_name} --force-output --warn "has already been installed."
        exit 1
    fi
fi

# check PHP7 requirement
if [ ! -f ${configfile} -a ! -f /etc/config.d/php7-fpm -a ! -f /etc/config.d/apache2_php7 ]
then
    # first time installation, force install of apache2_php7 package
    /var/install/bin/install-package -y -p 'apache2_php7' -v '1.1.14'

    if [ $? -eq 0 ]
    then
        myecho --pack ${module_name} --force-output --info "The required apache2_php7 package has successfully been installed."
    fi
fi

# backup existing file
if [ -f ${configfile} ]
then
    # move old files to backup directory and create backup
    /var/install/bin/backup-file --quiet ${module_name}

    myecho --pack ${module_name} "saving previous configuration file to ${installfile} ..."
    cp ${configfile} ${installfile}

    # activate maintenance mode
    myecho --pack ${module_name} "activating maintenance mode ..."
    /var/install/config.d/${module_name}.sh --maintenance-on
fi

# deinstall old software
myecho --pack ${module_name} "deinstalling previously installed software ..."
/usr/bin/eisman uninstall --update --auto --quiet ${module_name}

exit 0
